@@ -35,7 +35,7 @@ GML_DOUBLE_OR_NIL_REASON_TUPLE_LIST = ".//{http://www.opengis.net/gml/3.2}double
 GML_END_POSITION = ".//{http://www.opengis.net/gml/3.2}endPosition"
 GML_FILE_REFERENCE = ".//{http://www.opengis.net/gml/3.2}fileReference"
 GML_ID = "{http://www.opengis.net/gml/3.2}id"
-GML_IDENTIFIER = "{http://www.opengis.net/gml/3.2}identifier"
+GML_IDENTIFIER = ".//{http://www.opengis.net/gml/3.2}identifier"
 GML_MEASURE = ".//{http://www.opengis.net/gml/3.2}Measure"
 GML_NAME = ".//{http://www.opengis.net/gml/3.2}name"
 GML_POINT = ".//{http://www.opengis.net/gml/3.2}Point"
@@ -97,10 +97,10 @@ def get_stored_query_descriptions():
     descriptions = get_req_xml("DescribeStoredQueries")
     res = dict()
     root = ET.fromstring(descriptions)
-    for f in root.getchildren():
+    for f in root:
         if f.attrib['id'] == 'GetDataSetById':
             continue
-        f_ch = f.getchildren()
+        f_ch = list(f)
         desc = dict({'title': f_ch[0].text.strip(),
                      'description': f_ch[1].text.strip()})
         res[f.attrib['id']] = desc
@@ -123,4 +123,4 @@ def download_stored_query(query_id, args=None):
     else:
         raise NotImplementedError("No parser available for %s" % query_id)
 
-    return download_and_parse(query_id, args=args)
\ No newline at end of file
+    return download_and_parse(query_id, args=args)
